#! /usr/bin/env python3
# -*- coding: utf-8 -*-
"""
.. module:: TODO
   :platform: Unix
   :synopsis: TODO.

.. moduleauthor:: Aljosha Friemann <aljosha.friemann@gmail.com>

"""

from . import cli

cli.run()

# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4 fenc=utf-8
